==> kadu_0.6.0.2.orig.tar.gz: panelkadu/.configuration-ui-translations.cpp <==
QT_TRANSLATE_NOOP( "@default", "Geometry"                                               );
QT_TRANSLATE_NOOP( "@default", "Side"                                                   );
QT_TRANSLATE_NOOP( "@default", "Right"                                                  );
QT_TRANSLATE_NOOP( "@default", "Bottom"                                                 );
QT_TRANSLATE_NOOP( "@default", "Left"                                                   );
QT_TRANSLATE_NOOP( "@default", "Top"                                                    );
QT_TRANSLATE_NOOP( "@default", "Size"                                                   );
QT_TRANSLATE_NOOP( "@default", "User defined panel length"                              );
QT_TRANSLATE_NOOP( "@default", "Position"                                               );
QT_TRANSLATE_NOOP( "@default", "Length"                                                 );
QT_TRANSLATE_NOOP( "@default", "Behaviour"                                              );
QT_TRANSLATE_NOOP( "@default", "Activation time"                                        );
QT_TRANSLATE_NOOP( "@default", "Hide panel after"                                       );
QT_TRANSLATE_NOOP( "@default", "Use activation ranges"                                  );
QT_TRANSLATE_NOOP( "@default", "Activation ranges"                                      );
QT_TRANSLATE_NOOP( "@default", "Use spaces to separate ranges: '0-100 200-300 400-500'" );
QT_TRANSLATE_NOOP( "@default", "Don't hide panel when active (recommended)"             );

==> kadu_0.6.5.1.orig.tar.gz: panelkadu/.configuration-ui-translations.cpp <==
QT_TRANSLATE_NOOP( "@default", "Geometry"                                               );
QT_TRANSLATE_NOOP( "@default", "Side"                                                   );
QT_TRANSLATE_NOOP( "@default", "Right"                                                  );
QT_TRANSLATE_NOOP( "@default", "Bottom"                                                 );
QT_TRANSLATE_NOOP( "@default", "Left"                                                   );
QT_TRANSLATE_NOOP( "@default", "Top"                                                    );
QT_TRANSLATE_NOOP( "@default", "Size"                                                   );
QT_TRANSLATE_NOOP( "@default", "User defined panel length"                              );
QT_TRANSLATE_NOOP( "@default", "Position"                                               );
QT_TRANSLATE_NOOP( "@default", "Length"                                                 );
QT_TRANSLATE_NOOP( "@default", "Behaviour"                                              );
QT_TRANSLATE_NOOP( "@default", "Activation time"                                        );
QT_TRANSLATE_NOOP( "@default", "Hide panel after"                                       );
QT_TRANSLATE_NOOP( "@default", "Hiding margin"                                          );
QT_TRANSLATE_NOOP( "@default", "Use activation ranges"                                  );
QT_TRANSLATE_NOOP( "@default", "Activation ranges"                                      );
QT_TRANSLATE_NOOP( "@default", "Use spaces to separate ranges: '0-100 200-300 400-500'" );
QT_TRANSLATE_NOOP( "@default", "Don't hide panel when active"                           );
